@@ -13,6 +13,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <locale.h>
 
 #include <glib/gi18n.h>
 
@@ -38,18 +39,18 @@ static GOptionEntry entries[] = {
 };
 
 static const char *gdm_helpers[] = {
-	"gsd-a11y-keyboard",
-	"gsd-a11y-settings",
-	"gsd-clipboard",
-	"gsd-color",
-	"gsd-keyboard",
-	"gsd-media-keys",
-	"gsd-orientation",
-	"gsd-power",
-	"gsd-smartcard",
-	"gsd-sound",
-	"gsd-xrandr",
-	"gsd-xsettings"
+	"a11y-keyboard",
+	"a11y-settings",
+	"clipboard",
+	"color",
+	"keyboard",
+	"media-keys",
+	"orientation",
+	"power",
+	"smartcard",
+	"sound",
+	"xrandr",
+	"xsettings"
 };
 
 static gboolean
@@ -173,6 +174,7 @@ main (int argc, char **argv)
         bindtextdomain (GETTEXT_PACKAGE, GNOME_SETTINGS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
+        setlocale (LC_ALL, "");
 
         /* Work around https://bugzilla.gnome.org/show_bug.cgi?id=674885 */
         g_type_ensure (G_TYPE_DBUS_CONNECTION);
