@@ -284,6 +284,7 @@ input_info_guess_candidates (GsdInputInfo  *input,
 
 	if (input->capabilities & GSD_INPUT_IS_SCREEN_INTEGRATED) {
 		outputs[GSD_PRIO_MATCH_SIZE] = input_info_find_size_match (input, input->mapper->rr_screen);
+		found |= outputs[GSD_PRIO_MATCH_SIZE] != NULL;
 	}
 
 	split = g_strsplit (name, " ", -1);
@@ -559,6 +560,9 @@ input_info_remap (GsdInputInfo *input)
 
 	if (input->capabilities & GSD_INPUT_IS_PAD)
 		return;
+	if ((input->capabilities &
+	    (GSD_INPUT_IS_SCREEN_INTEGRATED | GSD_INPUT_IS_SYSTEM_INTEGRATED)) == 0)
+		return;
 
 	output = input_info_get_output (input);
 	settings_set_display (gsd_device_get_settings (input->device),
@@ -627,10 +631,15 @@ mapper_recalculate_candidates (GsdDeviceMapper *mapper)
 
 		input_info_update_settings_output (input);
 
-		/* Device has an output from settings */
-		if (input->output)
+		/* Avoid opaque device with an output from settings and
+		 * system-integrated devices that won't get remapped anyway
+		 */
+		if (input->output &&
+                    (input->capabilities & GSD_INPUT_IS_SCREEN_INTEGRATED) == 0)
 			continue;
 
+		/* reset the current output */
+		input_info_set_output (input, NULL, FALSE, FALSE);
 		input_info_guess_candidates (input, outputs);
 		mapping_helper_add (helper, input, outputs);
 	}
